#
# spec file for package musique
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           musique
Version:        1.10.1
Release:        1.21
Summary:        A different take on the music player
License:        GPL-3.0-only AND LGPL-2.1-only
Group:          Productivity/Multimedia/Sound/Players
URL:            https://flavio.tordini.org/musique
Source:         %{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(mpv) >= 0.29.0
BuildRequires:  pkgconfig(taglib)

%description
Musique is a music player designed by and for people that love
music. Musique does its best to stay out the way and keep you
focused on the only thing that really matters: Music.
You need to try it to really get it.
To set expectations right — Musique is not about podcasts or
internet radio; it's not about managing mobile devices and it has
no integrated music store.
It's about listening to beautiful music.

%lang_package

%prep
%setup -q

%if 0%{?suse_version} < 1500
SOURCE_DATE="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{_sourcedir}/%{name}.changes")"
export SOURCE_DATE_EPOCH="$(date -d "$SOURCE_DATE" '+%%s')"
%endif
# Remove build time references so build-compare can do its work
FAKE_BUILDDATE="$(LC_ALL=C date -u -d "@${SOURCE_DATE_EPOCH}" '+%%b %%e %%Y')"
sed -i "s/__DATE__/\"$FAKE_BUILDDATE\"/" src/aboutview.cpp

%build
%qmake5 \
  PREFIX=%{_prefix}            \
  QMAKE_CFLAGS="%{optflags}"   \
  QMAKE_CXXFLAGS="%{optflags}"
%make_build

%install
%qmake5_install
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc CHANGES TODO
%{_bindir}/%{name}
%{_datadir}/%{name}/
%exclude %{_datadir}/%{name}/locale/
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/icons/hicolor/*/
%dir %{_datadir}/icons/hicolor/*/apps/
%{_datadir}/icons/hicolor/*/apps/%{name}*

%files lang
%{_datadir}/%{name}/locale/

%changelog
* Mon Nov 30 2020 Cor Blom <cornelis@solcon.nl>
- Update to 1.10.1
  * No upstream changelog
* Mon Oct 26 2020 Cor Blom <cornelis@solcon.nl>
- Remove obsolete line: Recommends: %%{name}-lang = %%{version}
* Wed Oct 21 2020 Cor Blom <cornelis@solcon.nl>
- Correct licence
* Thu Oct  8 2020 Cor Blom <cornelis@solcon.nl>
- Remove lines for unsupported openSUSE versions
* Wed Oct  7 2020 Cor Blom <cornelis@solcon.nl>
- Update to 1.10
  - No upstream changelog
- Remove local qthelper.cpp
- Remove 0001-Use-a-local-copy-of-qthelper.hpp.patch
- Remove fixbuild.patch
* Wed Mar 11 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add a local qthelper.cpp copy. mpv >= 0.33 doesn't provide this
  header anymore and suggest keeping a local copy until using a
  better wrapper.
- Add 0001-Use-a-local-copy-of-qthelper.hpp.patch
* Fri Aug  9 2019 Cor Blom <cornelis@solcon.nl>
- Add fixbuild.patch
* Fri Aug  9 2019 Cor Blom <cornelis@solcon.nl>
- Update to 1.7:
  * Main change is swith to discogs for artist images, because
    lastfm stopped working.
* Thu May 16 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to 1.6:
  * Port from Phonon to MPV.
- Switch to SOURCE_DATE_EPOCH for fake build dates.
- Removed musique-fix-stringcompare.patch
* Sat Feb 11 2017 kieltux@gmail.com
- Update to 1.5:
  * Reworked icon
  * Now supports multiple disk and multiple artists albums
  * New Mac toolbar and icons
  * Retina display support
  * Fixed media keys on GNOME
  * Fixed collection updating on Mac App Store version
  * Fixed playlist header not displaying on tracks without album
  * New and updated translations
* Sat Oct 24 2015 tchvatal@suse.com
- Simply call qmake
- fix bnc#916899 by explicitly depending on sql backends of qt4
* Fri Jun 12 2015 sor.alexei@meowr.ru
- Change source target to GitHub.
- Remove musique-compilation-fix.patch.
* Sat Feb 28 2015 sor.alexei@meowr.ru
- Update to 1.4.
  * Enhancements to the search suggestions.
  * Make the volume handle red when volume is zero.
  * Hide the status bar when in the Info View.
  * Remote collections: do not update collection if dir does not
    exist or is empty.
  * Add --stop-after-this command line switch.
  * Fix duplicate tracks when playing an artist.
  * Add Stop After This Video GNOME action.
  * New and updated translations.
- Add musique-compilation-fix.patch.
- Remove gcc-4.7.patch.
- Remove musique-1.3-fix-toolbaricon.diff: fixed upstream.
- Spec cleanup.
- Add musique-lang package.
* Fri Nov  1 2013 cornelis@solcon.nl
- Added musique-1.3-fix-toolbaricon.diff to fix info icon on toolbar
* Fri Oct 11 2013 cornelis@solcon.nl
- Update to version 1.3:
  * Album and artist sorting
  * Album covers in the playlist
  * Faster artist and album views
  * Notification at end of collection scan
  * Notification support on Ubuntu
  * Gapless playback (Only works on Linux with the GStreamer Phonon backend)
  * Find more local covers (added GIF, PNG, BMP and JPEG file types)
  * Fixed homonymous albums from different artists being erroneously merged
  * Fixed albums not correctly sorted when playing an artist
  * Fixed play icon hover animation in Folders view
  * Fixed lyrics showing showing garbage in some cases
  * Fixed handling of tracks that have no associated album
  * New and updated translations
* Fri Feb  8 2013 cornelis@solcon.nl
- Update to version 1.2.1:
  * Faster painting of artist photos and album covers
  * Autoupdate on Mac and Windows
  * Updated Windows toolbar style
  * Ubuntu Ambiance theme integration
  * Fixed system language settings detection
  * New and updated translations
* Fri Oct 26 2012 cornelis@solcon.nl
- Update to version 1.2:
  * Fixed wrong artist names, please rescan your collection
  * Long artist names and album titles displaying incorrectly
  * Fixed disabled Info button when the playlist finishes
  * OS X Mountain Lion notifications
  * Mac Sandbox support
  * Compatible with OS X Mountain Lion Gatekeeper
  * Partial Retina Display support. Still using 1x bitmaps because of Qt not being ready
  * Fixed search box being erroneously focused on the Mac
  * Fixed wrong localization of some menu items on the Mac
  * Added missing menu item to restore hidden window, as per the OS X HIG
  * Unity & GNOME 3 actions (aka Quicklists)
  * CLI
  * New and updated translations
* Mon Jul 30 2012 cornelis@solcon.nl
- Added patch from debian to fix build with gcc 4.7
* Mon Feb 20 2012 saschpe@suse.de
- Spec file cleanup:
  * Set SPDX-style license
  * Add spec file license header
  * Removed outdated %%clean section
* Thu Feb 16 2012 cornelis@solcon.nl
- Update to version 1.1:
  * Last.fm scrobbling
  * Album covers from image files or embedded in audio files
  * Lyrics are now read from inside MP3 files when not available online
  * Faster music collection scanning
  * Album covers and artist photos are downloaded in the background
  * Album release year inside tags has now precedence over Last.fm often incorrect release year
  * Fixed duplicate tracks after rescan on Windows
  * Lots of minor UI enhancements
* Wed Oct 26 2011 alinm.elena@gmail.com
- Initial commit
